@@ -1972,6 +1972,8 @@ char		*tmp_levels;
 #ifdef MENU_COLOR
 	    (void) add_menu_coloring(bufp);
 #endif
+	} else if (match_varname(buf, "MONSTERCOLOR", 12)) {
+	    return parse_monster_color(bufp);
 	} else if (match_varname(buf, "GRAPHICS", 4)) {
 	    len = get_uchars(fp, buf, bufp, translate, FALSE,
 			     MAXPCHARS, "GRAPHICS");
